debug_print: Debug Print Function

View source: R/debug_print.R

debug_printR Documentation

Debug Print Function

Description

Prints a value to the console with a timestamp if the 'DEBUG' environment variable is set. This function is useful for conditional debugging output in R projects.

Usage

debug_print(value)

Arguments

value

The R object to be printed.


myownrobs documentation built on Nov. 5, 2025, 5:52 p.m.