| myownrobs | R Documentation |
Open the RStudio addin with the chat interface.
myownrobs(
api_url = paste0("https://myownhadley.com/api/v", packageVersion("myownrobs")$major)
)
api_url |
The API URL to use for requests. This parameter is for advanced users who want to specify an alternative backend URL and is rarely needed. |
No return value. Called for its side effects to launch the MyOwnRobs RStudio addin.
if (interactive()) {
myownrobs()
# Specify the API URL.
myownrobs("https://myownhadley.com/api/v0")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.