set_initial_project: Set the Initial State of the Project

View source: R/set_initial_project.R

set_initial_projectR Documentation

Set the Initial State of the Project

Description

Whether to save the initial state or to restore it.

Usage

set_initial_project(restore = FALSE)

Arguments

restore

If TRUE, it will restore the initial state. If FALSE, it will save the initial store in R's temp dir.


myownrobs documentation built on Nov. 5, 2025, 5:52 p.m.