myownrobs_server: MyOwnRobs Shiny Server
Description
MyOwnRobs Shiny Server
Usage
myownrobs_server(available_models, project_context)
Arguments
- available_models
List of available models to use, obtained with `get_available_models()`.
- project_context
The context of the session executing the addin, obtained with
`get_project_context()`.