View source: R/set_initial_project.R
| set_initial_project | R Documentation |
Whether to save the initial state or to restore it.
set_initial_project(restore = FALSE)
restore |
If TRUE, it will restore the initial state. If FALSE, it will save the initial store in R's temp dir. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.