| validate_command_args | R Documentation |
Checks if all required parameters for a given command are present in the provided arguments. This function ensures that the AI agent has supplied all necessary arguments before executing a command.
validate_command_args(command, args)
command |
A list representing the command definition, expected to contain a 'parameters' element. |
args |
A list of arguments provided to the command. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.